@@ -14,6 +14,8 @@ from datetime import datetime, timedelta
 from trexmodel.models.datastore.transaction_models import CustomerTransactionWithRewardDetails
 from trexanalytics import conf
 from trexmodel.models.datastore.ndb_models import convert_to_serializable_value
+from trexmodel import program_conf
+from trexmodel.models.datastore.redeem_models import CustomerRedeemedItemUpstream
 
 __REGISTERED_MERCHANT_TEMPLATE_UPSTREAM_SCHEMA = { 
                                                 'MerchantKey'           : 'key_in_str',
@@ -76,14 +78,15 @@ __CUSTOMER_REWARD_DATA_TEMPLATE_UPSTREAM_SCHEMA = {
                                             "RevertedDateTime"      : 'reverted_datetime',
                                             }
 
+
 __CUSTOMER_REDEMPTION_DATA_TEMPLATE_UPSTREAM_SCHEMA = {
-                                            "CustomerKey"           : 'redeemed_customer_key',
-                                            "MerchantKey"           : 'redeemed_merchant_acct_key',
-                                            "RedeemOutlet"          : 'redeemed_outlet_key',
+                                            "CustomerKey"           : 'customer_key',
+                                            "MerchantKey"           : 'merchant_key',
+                                            "RedeemedOutlet"          : 'redeemed_outlet_key',
                                             "TransactionId"         : 'transaction_id',
-                                            "RedeemAmount"          : 'redeem_amount',
+                                            "RedeemedAmount"        : 'redeemed_amount',
                                             "RewardFormat"          : 'reward_format',
-                                            "VoucherKeysList"       : 'redeemed_voucher_keys_list',
+                                            "VoucherKey"            : 'voucher_key',
                                             "RedeemedDateTime"      : 'redeemed_datetime',
                                             "Reverted"              : 'is_revert',
                                             "RevertedDateTime"      : 'reverted_datetime',
@@ -122,6 +125,9 @@ def __create_upstream(upstream_entity, upstream_template, dataset_name, table_na
         upstream_json[key] = convert_to_serializable_value(value, datetime_format='%Y-%m-%d %H:%M:%S', date_format='%Y-%m-%d', time_format='%H:%M:%S')
     
     logger.debug('-------------------------------------------------')
+    logger.debug('dataset_name=%s', dataset_name)
+    logger.debug('table_name=%s', table_name)
+    logger.debug('upstream_template=%s', upstream_template)
     logger.debug('upstream_json=%s', upstream_json)
     logger.debug('-------------------------------------------------')
     UpstreamData.create(dataset_name, table_name, upstream_template, [upstream_json])
@@ -206,7 +212,45 @@ def create_merchant_customer_redemption_upstream_for_merchant(redemption_details
     account_code        = merchant_acct.account_code.replace('-','')
     final_table_name    = '{}_{}_{}'.format(table_name, account_code, streamed_datetime.strftime('%Y%m%d'))
     
-    __create_upstream(redemption_details, MERCHANT_CUSTOMER_REDEMPTION_TEMPLATE, MERCHANT_DATASET, final_table_name, 
+    upstream_data_list = []
+    
+    transaction_id      = redemption_details.transaction_id
+    redeemed_outlet_key = redemption_details.redeemed_outlet_key
+    merchant_key        = redemption_details.redeemed_merchant_acct_key
+    customer_key        = redemption_details.redeemed_customer_key
+    redeemed_amount     = redemption_details.redeemed_amount
+    reward_format       = redemption_details.reward_format
+    redeemed_datetime   = redemption_details.redeemed_datetime
+    
+    for reward_format, details in redemption_details.redeemed_summary.items():
+        if reward_format in (program_conf.REWARD_FORMAT_POINT, program_conf.REWARD_FORMAT_STAMP):
+            upstream_data_list.append(CustomerRedeemedItemUpstream(
+                                        customer_key        = customer_key,
+                                        merchant_key        = merchant_key,
+                                        redeemed_outlet_key = redeemed_outlet_key,
+                                        transaction_id      = transaction_id,
+                                        redeemed_amount     = redeemed_amount,
+                                        reward_format       = reward_format,
+                                        redeemed_datetime   = redeemed_datetime,
+                                        
+                                        
+                                    ))
+        else:
+            for voucher_key, voucher_count in details.items():
+                upstream_data_list.append(CustomerRedeemedItemUpstream(
+                                        customer_key        = customer_key,
+                                        merchant_key        = merchant_key,
+                                        redeemed_outlet_key = redeemed_outlet_key,
+                                        transaction_id      = transaction_id,
+                                        redeemed_amount     = voucher_count,
+                                        reward_format       = program_conf.REWARD_FORMAT_VOUCHER,
+                                        voucher_key         = voucher_key,
+                                        redeemed_datetime   = redeemed_datetime,
+                                        
+                                        
+                                    ))
+    for upstream_data in upstream_data_list:
+        __create_upstream(upstream_data, MERCHANT_CUSTOMER_REDEMPTION_TEMPLATE, MERCHANT_DATASET, final_table_name, 
                       streamed_datetime=streamed_datetime, Reverted=False, RevertedDateTime=None)
     
 def create_merchant_customer_redemption_reverted_upstream_for_merchant(redemption_details, reverted_datetime):
