@@ -15,7 +15,7 @@ from trexanalytics.conf import BIGQUERY_GCLOUD_PROJECT_ID, SYSTEM_DATASET, MERCH
 customer_analytics_data_bp = Blueprint('customer_analytics_data_bp', __name__,
                                  template_folder='templates',
                                  static_folder='static',
-                                 url_prefix='/analytics/customer')
+                                 url_prefix='/analytics/cust')
 
 logger = logging.getLogger('query')
 
@@ -297,8 +297,8 @@ def execute_all_registered_customer_by_year_month(bg_client, project_id, dataset
 def process_all_registered_customer_by_year_month(job_result_rows):
     return process_job_result_into_category_and_count(job_result_rows)
 
-query_customer_data_api.add_resource(QueryAllCustomerGrowthByYearMonth,   '/all-customer-growth-by-year-month')
-query_customer_data_api.add_resource(QueryMerchantCustomerGrowthByYearMonth,   '/merchant-customer-growth-by-year-month')
-query_customer_data_api.add_resource(QueryMerchantCustomerCountByDateRange,   '/merchant-customer-count-by-date-range')
-query_customer_data_api.add_resource(QueryMerchantCustomerGenderByDateRange,   '/merchant-customer-gender-by-date-range')
-query_customer_data_api.add_resource(QueryMerchantCustomerAgeGroupByDateRange,   '/merchant-customer-age-group-by-date-range')
+query_customer_data_api.add_resource(QueryAllCustomerGrowthByYearMonth,   '/all-cust-growth-by-year-month')
+query_customer_data_api.add_resource(QueryMerchantCustomerGrowthByYearMonth,   '/merchant-cust-growth-by-year-month')
+query_customer_data_api.add_resource(QueryMerchantCustomerCountByDateRange,   '/merchant-cust-count-by-date-range')
+query_customer_data_api.add_resource(QueryMerchantCustomerGenderByDateRange,   '/merchant-cust-gender-by-date-range')
+query_customer_data_api.add_resource(QueryMerchantCustomerAgeGroupByDateRange,   '/merchant-cust-age-group-by-date-range')
